==> ReleaseV1.1.0.tar.gz: winginterfacelibrary/src/Interface/IConnectService.cs <==
﻿using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Device;
using WingInterfaceLibrary.Result.Device;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 鉴权服务接口
    /// </summary>
    /// <value>设备信息接口</value>
    /// <example>设备端API</example>
    [System.ComponentModel.Description("DeviceService")]
    public interface IConnectService
    {
        /// <summary>
        /// 连接云服务
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>授权响应</returns>
        /// <remarks>POST</remarks>
        /// <errorCodes>DeviceUniqueCodeEmpty,DeviceModelEmpty,DeviceTypeEmpty,SoftwareVersionEmpty,SystemVersionEmpty,CPUModelEmpty</errorCodes>
        Task<ConnectResult> ConnectAsync(ConnectRequest request);

        /// <summary>查询当前设备信息</summary>
        /// <param name="request">请求对象</param>
        /// <returns>设备信息</returns>
        /// <remarks>POST</remarks>
        Task<CacheDeviceDTO> GetDeviceByTokenAsync(TokenRequest request);

        /// <summary>断开云服务</summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        Task<bool> DisConnectAsync(TokenRequest request);

                /// <summary>
        /// 设置敏感信息是否加密请求
        /// </summary>
        /// <param name="request">设置敏感信息是否加密请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> SetDeviceIsEncryptedShowAsync(SetDeviceIsEncryptedShowRequest request);
    }
}

==> ReleaseV1.1.3.tar.gz: winginterfacelibrary/src/Interface/IConnectService.cs <==
﻿using System.Threading.Tasks;
using WingInterfaceLibrary.DTO.Device;
using WingInterfaceLibrary.Request;
using WingInterfaceLibrary.Request.Device;
using WingInterfaceLibrary.Result.Device;

namespace WingInterfaceLibrary.Interface
{
    /// <summary>
    /// 鉴权服务接口
    /// </summary>
    /// <docFirstDirectory>设备端API</docFirstDirectory>
    /// <docSecondDirectory>设备信息接口</docSecondDirectory>
    public interface IConnectService
    {
        /// <summary>
        /// 连接云服务
        /// </summary>
        /// <param name="request">请求对象</param>
        /// <returns>授权响应</returns>
        /// <remarks>POST</remarks>
        /// <errorCodes>DeviceUniqueCodeEmpty,DeviceModelEmpty,DeviceTypeEmpty,DeviceTypeError,DeviceModelError,SoftwareVersionEmpty,SystemVersionEmpty,CPUModelEmpty</errorCodes>
        Task<ConnectResult> ConnectAsync(ConnectRequest request);

        /// <summary>查询当前设备信息</summary>
        /// <param name="request">请求对象</param>
        /// <returns>设备信息</returns>
        /// <remarks>POST</remarks>
        Task<CacheDeviceDTO> GetDeviceByTokenAsync(TokenRequest request);

        /// <summary>断开云服务</summary>
        /// <param name="request">请求对象</param>
        /// <returns>是否成功</returns>
        /// <value>true</value>
        /// <remarks>POST</remarks>
        Task<bool> DisConnectAsync(TokenRequest request);

        /// <summary>
        /// 设置敏感信息是否加密请求
        /// </summary>
        /// <param name="request">设置敏感信息是否加密请求实体</param>
        /// <returns>是否成功</returns>
        Task<bool> SetDeviceIsEncryptedShowAsync(SetDeviceIsEncryptedShowRequest request);
    }
}
